import axios from "axios"

axios.defaults.xsrfCookieName = "csrftoken"
axios.defaults.xsrfHeaderName = "X-CSRFTOKEN"

const apiBase = "/api/v2/"

const sleep = m => new Promise(r => setTimeout(r, m))

const returnDataIfNotError = async (response) => {
  if (response.status >= 400) {
    throw new Error(response.data.detail || "An error occurred")
  }
  await sleep(500)
  return response.data
}

const getMe = async () => {
  return await axios.get(`${apiBase}me`)
    .then(res => returnDataIfNotError(res))
}

const listStreams = async (filter = null) => {
  return await axios.get(`${apiBase}config/streams`)
    .then(res => returnDataIfNotError(res))
}

const getStream = async (id) => {
  return await axios.get(`${apiBase}config/streams/${id}`)
    .then(res => returnDataIfNotError(res))
}

const deleteStream = async (id) => {
  return await axios.delete(`${apiBase}config/streams/${id}`)
    .then(res => returnDataIfNotError(res))
}

const createStream = async (data) => {
  return await axios.post(`${apiBase}config/streams`, data)
    .then(res => returnDataIfNotError(res))
}

const getRestream = async (id) => {
  return await axios.get(`${apiBase}config/restreams/${id}`)
    .then(res => returnDataIfNotError(res))
}

const listRestreams = async () => {
  return await axios.get(`${apiBase}config/restreams`)
    .then(res => returnDataIfNotError(res))
}

const patchRestream = async (id, data) => {
  return await axios.patch(`${apiBase}config/restreams/${id}`, data)
    .then(res => returnDataIfNotError(res))
}

export { getMe, listStreams, getStream, deleteStream, createStream, getRestream, listRestreams, patchRestream }